<?php

/**
 * @file
 * Administration settings for the Manticore module.
 */

/**
 * Menu callback; Manticore administration settings.
 */
function manticore_admin() {
  $form['#attributes'] = array('enctype' => "multipart/form-data");
  $form['general'] = array(
    '#type' => 'fieldset',
    '#title' => t('General settings'),
    '#description' => t('These are settings that apply to your site globally.'),
    '#collapsed' => FALSE,
    '#collapsible' => TRUE,
  );
  $form['general']['manticore_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Key'),
    '#description' => t('The Manticore MTC_KEY value.'),
    '#default_value' => variable_get('manticore_key', ''),
    '#required' => TRUE,
  );
  $form['general']['manticore_group'] = array(
    '#type' => 'textfield',
    '#title' => t('Group'),
    '#description' => t('The Manticore MTC_GROUP value.'),
    '#default_value' => variable_get('manticore_group', ''),
    '#required' => TRUE,
  );
  $form['general']['manticore_id'] = array(
    '#type' => 'textfield',
    '#title' => t('ID'),
    '#description' => t('The Manticore MTC_ID value.'),
    '#default_value' => variable_get('manticore_id', ''),
    '#required' => TRUE,
  );
  $form['general']['manticore_method'] = array(
    '#type' => 'radios',
    '#title' => t('Method'),
    '#description' => t('The method in which the Manticore API will be called.'),
    '#default_value' => variable_get('manticore_method', 'ManticoreDrupal'),
    '#required' => TRUE,
    '#options' => array(
      'ManticoreDrupal' => t('drupal_http_request()'),
      'ManticoreCurl' => t('cURL'),
    ),
  );

  $form['fields'] = array(
    '#type' => 'fieldset',
    '#title' => t('Fields'),
    '#description' => t('Choose which fields can be sent off to Manticore.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['fields']['manticore_availablefields'] = array(
    '#type' => 'textarea',
    '#title' => t('Fields'),
    '#description' => t('Each field is seperated by a new line. Each field has a name, and a type, seperated by a "|". Example: fieldname|type . The default type is "string".'),
    '#default_value' => manticore_availablefields(FALSE),
    '#rows' => count(manticore_availablefields()),
  );

  // The Installation Code and Application File
  $form['installationcode'] = array(
    '#type' => 'fieldset',
    '#title' => t('Installation Code'),
    '#description' => t('Allows injection of the installation code for Manticore tracking.'),
    '#collapsed' => FALSE,
    '#collapsible' => TRUE,
  );
  $form['installationcode']['manticore_installationcode'] = array(
    '#type' => 'checkbox',
    '#title' => t('Installation Code'),
    '#description' => t('Inject the Manticore installation code at the footer of the site.'),
    '#default_value' => variable_get('manticore_installationcode', FALSE),
  );
  $form['installationcode']['manticore_applicationfile'] = array(
    '#type' => 'file',
    '#title' => t('Application File'),
    '#description' => t('Upload the downloaded Manticore application file here from the Installation Code tab.'),
    '#prefix' => variable_get('manticore_applicationfile_filepath', ''),
    '#size' => 20,
  );
  $form['#submit'][] = 'manticore_admin_applicationfile';
  return system_settings_form($form);
}

/**
 * Form API callback to handle the file upload.
 */
function manticore_admin_applicationfile($element, &$form_state) {
  if ($file = file_save_upload('manticore_applicationfile')) {
    if (file_copy($file)) {
      variable_set('manticore_applicationfile_filepath', $file->filepath);
    }
    else {
      form_set_error('manticore_admin', t("Failed to save the file."));
    }
  }
}

